% Text Mining with MATLAB 2nd Edition
% www.http://www.textmininglab.net/

% CHAPTER 2: Handling Text Data

clear
disp('Example 2.1 ------------------------------------------------------');
text_string = 'Hello, this is a string!'                             %(2.1)
pause;

disp('Example 2.2 ------------------------------------------------------');
whos                                                                 %(2.2)
pause;

disp('Example 2.3 ------------------------------------------------------');
codes = cast(text_string,'int16')                                   %(2.3a)
whos                                                                %(2.3b)
pause;

disp('Example 2.4 ------------------------------------------------------');
cast(codes,'char')                                                  %(2.4a)
char(codes)                                                         %(2.4b)
pause;

disp('Example 2.5 ------------------------------------------------------');
list = ['This is the first string ';'This is the second string']    %(2.5a)
whos list                                                           %(2.5b)
pause;

disp('Example 2.6 ------------------------------------------------------');
% You need to comment this example to be able to run the full script
list = ['This is the first string';'This is the second string']      %(2.6)
pause;

disp('Example 2.7 ------------------------------------------------------');
dataset = ['name  age';'mark   35';'beth   26';'peter  39']         %(2.7a)
names = dataset(2:end,1:end-4)                                      %(2.7b)
ages = dataset(2:end,end-1:end)                                     %(2.7c)
people_in_their_30s = dataset(dataset(:,end-1)=='3',1:end-4)        %(2.7d)
pause;

disp('Example 2.8 ------------------------------------------------------');
cell_array = {'Hello World',eye(3);5+j,dataset}                      %(2.8)
pause;

disp('Example 2.9 ------------------------------------------------------');
cell_array{1,1}                                                     %(2.9a)
cell_array{1,2}                                                     %(2.9b)
cell_array{2,1}                                                     %(2.9c)
cell_array{2,2}                                                     %(2.9d)
pause;

disp('Example 2.10 -----------------------------------------------------');
list={'This is the 1st string';'This is the 2nd one';'And the 3rd'} %(2.10)
pause;

disp('Example 2.11 -----------------------------------------------------');
list{1} % retrieves the first string in list                       %(2.11a)
list{2} % retrieves the second string                              %(2.11b)
list{3} % retrieves the third string                               %(2.11c)
pause;

disp('Example 2.12 -----------------------------------------------------');
% retrieves the first four characters in the first string          %(2.12a)
list{1}(1:4)
% retrieves the last three characters in the second string         %(2.12b)
list{2}(end-2:end)
% retrieves all non-white-space characters in the third string     %(2.12c)
list{3}(not(list{3}==' '))
pause;

disp('Example 2.13 -----------------------------------------------------');
with_braces = list{1}                                              %(2.13a)
with_parenthesis = list(1)                                         %(2.13b)
whos list with_braces with_parenthesis                             %(2.13c)
pause;

disp('Example 2.14 -----------------------------------------------------');
structure = struct('f1','Hello World','f2',eye(3),'f3',5+j);       %(2.14a)
structure.f4.names = ['mark ';'beth ';'peter'];                    %(2.14b)
structure.f4.ages = [35;26;39];
pause;

disp('Example 2.15 -----------------------------------------------------');
structure.f1 % retrieves field f1                                  %(2.15a)
structure.f2 % retrieves field f2                                  %(2.15b)
structure.f3 % retrieves field f3                                  %(2.15c)
structure.f4 % retrieves field f4                                  %(2.15d)
pause;

disp('Example 2.16 -----------------------------------------------------');
structure.f4.ages' % retrieves and transposes subfield ages of f4  %(2.16a)
structure.f4.names % retrieves subfield names of f4                %(2.16b)
% retrieves the second row of subfield names of f4                 %(2.16c)
structure.f4.names(2,:)
pause;

disp('Example 2.17 -----------------------------------------------------');
data=struct('name',{'mark';'beth';'peter'},'age',{'35';'26';'39'})  %(2.17)
pause;

disp('Example 2.18 -----------------------------------------------------');
datacell = struct2cell(data)                                       %(2.18a)
datafields = fieldnames(data)                                      %(2.18b)
pause;

disp('Example 2.19 -----------------------------------------------------');
databack = cell2struct(datacell,datafields,1)                      %(2.19a)
databack(1)                                                        %(2.19b)
databack(2)                                                        %(2.19c)
databack(3)                                                        %(2.19d)
pause;

disp('Example 2.20 -----------------------------------------------------');
text_string = "Hello, this is a string!"                           %(2.20a)
whos text_string                                                   %(2.20b)
pause; 

disp('Example 2.21 -----------------------------------------------------');
char_array = char(text_string) % to character array                %(2.21a)
string_scalar = string(char_array) % back to string scalar         %(2.21b)
whos char_array string_scalar                                      %(2.21c)
pause; 

disp('Example 2.22 -----------------------------------------------------');
strarray = ["mark ","beth","peter";35,26,39]                        %(2.22)
pause; 

disp('Example 2.23 -----------------------------------------------------');
strarray(:,2)                                                      %(2.23a)
strarray{:,2}                                                      %(2.23b)
pause; 

disp('Example 2.24 -----------------------------------------------------');
strarray{1,2}(3:4)                                                 %(2.24a)
strarray{1,3}(strarray{1,3}~='e')                                  %(2.24b)
pause; 

disp('Example 2.25 -----------------------------------------------------');
cellarray = cellstr(strarray) % from string array to cell array    %(2.25a)
backtostrarray = string(cellarray) % back to string array          %(2.25b)
whos strarray cellarray backtostrarray                             %(2.25c)
pause; 

disp('Example 2.26 -----------------------------------------------------');
strarray(2,4)=""                                                    %(2.26)
pause;

disp('Example 2.27 -----------------------------------------------------');
cellstr(strarray)                                                  %(2.27a)
string(cellstr(strarray))                                          %(2.27b)
pause;

disp('Example 2.28 -----------------------------------------------------');
lookfor blanks % searches for the string 'blanks' in all M-files   %(2.28a)
help blanks % looks at the description of function blanks          %(2.28b)
pause;

disp('Example 2.29 -----------------------------------------------------');
iskeyword('start') % valid variable name                           %(2.29a)
iskeyword('end') % not a valid name as it is MATLAB keyword        %(2.29b)
pause;

disp('Example 2.30 -----------------------------------------------------');
pause(5) % halts the execution for 5 seconds                       %(2.30a)
pause % halts the execution until a key is hit                     %(2.30b)
pause;

disp('Example 2.31 -----------------------------------------------------');
keyboard % halts the program and gives access to the command window %(2.31)
% Type 'dbcont' to continue program execution ('return' is deprecated!)
pause;

disp('Example 2.32 -----------------------------------------------------');
r = input('How old are you? ') % prompts for a numeric variable    %(2.32a)
s = input('What is your name? ','s') % prompts for a text input    %(2.32b)
pause;

disp('Example 2.33 -----------------------------------------------------');
disp(dataset) % displays the variable 'dataset' defined in (2.7a)   %(2.33)
pause;

disp('Example 2.34 -----------------------------------------------------');
q1 = 'What day is it?'; q2 = 'What time is it?';                   %(2.34a)
today = inputdlg({q1,q2});
q1 = 'What is your favorite fruit?';                               %(2.34b)
fruit = questdlg(q1,'','apple','banana','mango','mango');
msg = 'This is the end of section 2.5.';                           %(2.34c)
uiwait(msgbox(msg,'','modal'));
pause;
